==> simple_survey-8.x-1.23.tar.gz: simple_survey/src/Controller/SimpleSurveyController.php <==
<?php

namespace Drupal\simple_survey\Controller;

use Drupal\Core\Controller\ControllerBase;
use Drupal\Core\Datetime\DateFormatter;
use Drupal\Core\Logger\LoggerChannelFactoryInterface;
use Drupal\Core\Messenger\MessengerInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;
use Symfony\Component\HttpFoundation\Response;
use Drupal\simple_survey\Service\BigQueryConnect;
use Drupal\simple_survey\Service\ResponseExportService;
use Drupal\Component\Datetime\TimeInterface;
use Drupal\Core\File\FileSystemInterface;
use Drupal\Core\Messenger\Messenger;
use Drupal\Core\Url;
use Drupal\simple_survey\Entity\SimpleSurvey;
use Drupal\simple_survey\Entity\SimpleSurveyInterface;
use SplFileObject;

/**
 * Class SimpleSurveyController.
 *
 * @package Drupal\simple_survey\Controller
 */
class SimpleSurveyController extends ControllerBase {

  /**
   * The modules machine name.
   *
   * @var string
   */
  private $moduleName = 'simple_survey';

  /**
   * Drupal\Core\Messenger\MessengerInterface definition.
   *
   * @var \Drupal\Core\Messenger\MessengerInterface
   */
  protected $messenger;

  /**
   * Drupal\Core\Logger\LoggerChannelFactory definition.
   *
   * @var \Drupal\Core\Logger\LoggerChannelInterface
   */
  protected $logger;

  /**
   * Drupal date formatter service.
   *
   * @var \Drupal\Core\Datetime\DateFormatter
   */
  protected $dateFormatter;

  /**
   * Response export service.
   *
   * @var \Drupal\simple_survey\Service\BigQueryConnect
   */
  protected $bigQuery;

  /**
   * Response export service.
   *
   * @var \Drupal\simple_survey\ResponseExportService
   */
  protected $responseExport;

  /**
   * The Drupal Time Service.
   *
   * @var \Drupal\Component\Datetime\TimeInterface
   */
  protected $time;

  /**
   * File System service.
   *
   * @var \Drupal\Core\File\FileSystem
   */
  protected $fileSystem;

  /**
   * Simple Survery Controller constructor.
   *
   * @todo Look into creating a service to handle DI. Doing a janky call in feedbackjs.module
   *
   * @param \Drupal\Core\Messenger\MessengerInterface $messenger
   *   The Drupal messenger service.
   * @param Drupal\Core\Datetime\DateFormatter $dateFormatter
   *   The Drupal date formatter service.
   * @param \Drupal\Core\Logger\LoggerChannelFactoryInterface $logger_factory
   *   The logger factory service.
   * @param \Drupal\simple_survey\Service\BigQueryConnect $big_query
   *   The BigQuery Connection service.
   * @param \Drupal\simple_survey\ResponseExportService $response_export_service
   *   The response export service.
   * @param \Drupal\Component\Datetime\TimeInterface $time
   *   The Drupal time service.
   * @param \Drupal\Core\File\FileSystemInterface $fileSystemInterface
   *   The Drupal file system service.
   */
  public function __construct(
    MessengerInterface $messenger,
    DateFormatter $dateFormatter,
    LoggerChannelFactoryInterface $logger_factory,
    BigQueryConnect $big_query,
    ResponseExportService $response_export_service,
    TimeInterface $time,
    FileSystemInterface $fileSystemInterface) {
    $this->messenger = $messenger;
    $this->dateFormatter = $dateFormatter;
    $this->logger = $logger_factory->get($this->moduleName);
    $this->bigQuery = $big_query;
    $this->responseExport = $response_export_service;
    $this->time = $time;
    $this->fileSystem = $fileSystemInterface;

    $this->modulePath = drupal_get_path('module', $this->moduleName);
  }

  /**
   * Dependency Injection.
   *
   * @inheritDoc
   */
  public static function create(ContainerInterface $container) {
    return new static(
      $container->get('messenger'),
      $container->get('date.formatter'),
      $container->get('logger.factory'),
      $container->get('simple_survey.big_query'),
      $container->get('simple_survey.response_export'),
      $container->get('datetime.time'),
      $container->get('file_system')
    );
  }

  /**
   * Allows user to download the temporary generated response survey.
   *
   * @param string $simple_survey
   *   The survey machine name.
   * @param string $filename
   *   The survey filename.
   *
   * @return mixed
   *   Will return either a file or redirect to the requesting survey.
   */
  public function getTemporaryFile($simple_survey, $filename) {

    $filepath = $this->fileSystem->realpath("temporary://")
      . '/' . $filename;

    if (file_exists($filepath)) {
      $file = new SplFileObject($filepath, 'r');

      $headerResponse = new Response();
      $headerResponse->headers->set('Content-Type', 'test/csv; charset=utf-8');
      $headerResponse->headers->set('Content-Disposition', 'attachment; filename="'
      . $filename);
      $headerResponse->headers->set('Content-Length', $file->getSize());
      $headerResponse->sendHeaders();

      $file->fpassthru();

      return $headerResponse;
    }
    else {
      $this->messenger()->addWarning($this->t(':filename no longer exist. Please generate a new download.', [
        ':filename' => $filename,
      ]));

      return $this->redirect('entity.simple_survey.edit_form', [
        'simple_survey' => $simple_survey,
      ]);
    }
  }

  /**
   * Submits CSV file to BigQuery.
   *
   * @param string $filename
   *   The name of the file to be submitted.
   * @param string $survey
   *   The survey the file is being submitted for.
   * @param string $dataset
   *   The datasest to submit to.
   * @param string $table
   *   The table to submit to.
   * @param array|object $context
   *   The batch context.
   *
   * @return mixed
   *   The
   */
  public static function submitData(
    string $filename,
    string $survey,
    string $dataset,
    string $table,
    &$context) {
    $filepath = \Drupal::service('file_system')->realpath("temporary://")
      . '/' . $filename;
    $bigQuery = \Drupal::service('simple_survey.big_query');
    $messenger = \Drupal::messenger();
    $logger = \Drupal::logger('simple_survey');
    $simpleSurvey = SimpleSurvey::load($survey);
    $isCli = PHP_SAPI === 'cli';

    $contextMessage = t('Sending :filename to :table in BigQuery', [
      ':filename' => $filename,
      ':table' => $table,
    ]);

    $context['message'] = $contextMessage;
    $logger->info($contextMessage);

    $bigQuery->setSurvey($simpleSurvey);

    if (!$bigQuery->checkConfigured()) {
      if (!$isCli) {
        $messenger->addWarning('BigQuery is not configured.');
      }

      $logger->warning('BigQuery is not configured.');
      return;
    }
    else {
      $updated = $bigQuery->updateTable(
        $dataset,
        $table,
        fopen($filepath, 'r')
      );

      // Check if the job has errors.
      if (!$updated) {
        $errorMessage = t('Data to be imported to :dataset.:table could not be sent for :survey.', [
          ':survey' => $simpleSurvey->label(),
          ':dataset' => $dataset,
          ':table' => $table,
        ]);
        $logger->error($errorMessage);
      }
      else {
        $statusMessage = t('Data for :dataset.:table sent to BigQuery for :survey.', [
          ':survey' => $simpleSurvey->label(),
          ':dataset' => $dataset,
          ':table' => $table,
        ]);
        if (!$isCli) {
          $messenger->addMessage($statusMessage);
        }
        $logger->info($statusMessage);
      }
    }

    $context['finished'] = TRUE;
  }

  /**
   * Completion callback for PrintBookForm batch.
   *
   * @param bool $success
   *   Boolean value that specifies batch success.
   * @param array $results
   *   Array that contains results from batch context.
   * @param array $operations
   *   Array that contains batch operations.
   */
  public static function finishedProcessingBq(bool $success, array $results, array $operations) {
    $status = Messenger::TYPE_STATUS;

    if ($success) {
      $message = t('Data sent to BigQuery for :survey.', [
        ':survey' => $results['survey'],
      ]);

      \Drupal::logger('simple_survey')->info($message);
    }
    else {
      $message = t('Could not send data to BigQuery for :survey.', [
        ':survey' => $results['survey'],
      ]);

      $status = Messenger::TYPE_ERROR;
      \Drupal::logger('simple_survey')->error($message);
    }

    \Drupal::messenger()->addMessage($message, $status);
  }

  /**
   * Displays the response as CSV.
   *
   * @return \Symfony\Component\HttpFoundation\Response
   *   Returns a JSON Response.
   */
  public function responseOutput(SimpleSurveyInterface $simple_survey) {
    $fileTime = $this->dateFormatter->format($this->time->getRequestTime(), 'custom', 'YdmHis');
    $filename = $simple_survey->id() . '-survey-export-' . $fileTime . '.csv';
    $survey = $simple_survey->id();

    $batch = [
      'title' => $this->t('Create response download for %survey', [
        '%survey' => $simple_survey->label(),
      ]),
      'operations' => [
        [
          '\Drupal\simple_survey\Service\ResponseExportService::processData',
          [
            $filename,
            $survey,
          ],
        ],
      ],
      'finished' => '\Drupal\simple_survey\Service\ResponseExportService::finishedFileProcessing',
      'init_message' => $this->t('Processing for data from @source', [
        '@source' => $simple_survey->label(),
      ]),
      'progress_message' => $this->t('@current out of @total processed from @source. Estimated: @estimate', [
        '@source' => $simple_survey->label(),
      ]),
      'error_message' => $this->t('The export progress has encountered an error.'),
    ];

    batch_set($batch);

    return batch_process(Url::fromRoute('entity.simple_survey.edit_form', [
      'simple_survey' => $survey,
    ]));
  }

  /**
   * Displays the response as CSV.
   *
   * @return \Symfony\Component\HttpFoundation\Response
   *   Returns a JSON Response.
   */
  public function bigQueryExport(SimpleSurveyInterface $simple_survey) {
    $filename = $simple_survey->id() . '-survey-export.csv';
    $survey = $simple_survey->id();

    $batch = [
      'title' => $this->t('Send Data to BigQuery for %survey', [
        '%survey' => $simple_survey->label(),
      ]),
      'operations' => [
        [
          '\Drupal\simple_survey\Service\ResponseExportService::processData',
          [
            $filename,
            $survey,
          ],
        ],
        [
          '\Drupal\simple_survey\Controller\SimpleSurveyController::submitData',
          [
            $filename,
            $survey,
            $simple_survey->get('bigQueryDataset'),
            $simple_survey->get('bigQueryTable'),
          ],
        ],
      ],
      'finished' => '\Drupal\simple_survey\Controller\SimpleSurveyController::finishedProcessingBq',
      'init_message' => $this->t('Initializing BiqQuery connection for @source', [
        '@source' => $simple_survey->label(),
      ]),
      'progress_message' => $this->t('Data being sent to BiqQuery for @source.', [
        '@source' => $simple_survey->label(),
      ]),
      'error_message' => $this->t('The export progress has encountered an error.'),
    ];

    batch_set($batch);

    return batch_process(Url::fromRoute('entity.simple_survey.edit_form', [
      'simple_survey' => $survey,
    ]));
  }

  /**
   * Submits all data to a bigQuery table via cron.
   */
  public function bigQueryCronUpdate() {
    if (!$this->bigQuery->checkConfigured()) {
      $this->logger->alert('BigQuery is not configured.');
    }
    else {
      $surveys = SimpleSurvey::loadMultiple();

      foreach ($surveys as $survey) {
        if (!$survey->isSurveyActive()) {
          continue;
        }

        $this->responseExport->survey = $survey;
        $csv = $this->responseExport->convertDataToCsv();

        $updated = $this->bigQuery->updateTable('survey_tool', 'survey_response', $csv);

        // Check if the job has errors.
        if ($updated) {
          $this->logger->info('Completed Updating BigQuery Table for ' . $survey->label());
        }
      }
    }
  }

  /**
   * Manual submission to BigQuery.
   *
   * @return \Symfony\Component\HttpFoundation\Response
   *   Returns response object.
   */
  public function bigQueryManualUpdate(SimpleSurveyInterface $simple_survey) {
    $filename = $simple_survey->id() . '-survey-export.csv';
    $survey = $simple_survey->id();

    $batch = [
      'title' => $this->t('Send Data to BigQuery for %survey', [
        '%survey' => $simple_survey->label(),
      ]),
      'operations' => [
        [
          '\Drupal\simple_survey\Service\ResponseExportService::processData',
          [
            $filename,
            $survey,
          ],
        ],
        [
          '\Drupal\simple_survey\Controller\SimpleSurveyController::submitData',
          [
            $filename,
            $survey,
            $simple_survey->get('bigQueryDataset'),
            $simple_survey->get('bigQueryTable'),
          ],
        ],
      ],
      'finished' => '\Drupal\simple_survey\Controller\SimpleSurveyController::finishedProcessingBq',
      'init_message' => $this->t('Initializing BiqQuery connection for @source', [
        '@source' => $simple_survey->label(),
      ]),
      'progress_message' => $this->t('Data being sent to BiqQuery for @source. Time left: @estimate', [
        '@source' => $simple_survey->label(),
      ]),
      'error_message' => $this->t('The export progress has encountered an error.'),
    ];

    batch_set($batch);

    return batch_process(Url::fromRoute('entity.simple_survey.edit_form', [
      'simple_survey' => $survey,
    ]));
  }

}

==> simple_survey-8.x-1.27.tar.gz: simple_survey/src/Controller/SimpleSurveyController.php <==
<?php

namespace Drupal\simple_survey\Controller;

use Drupal\Core\Controller\ControllerBase;
use Drupal\Core\Datetime\DateFormatter;
use Drupal\Core\Logger\LoggerChannelFactoryInterface;
use Drupal\Core\Messenger\MessengerInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;
use Symfony\Component\HttpFoundation\Response;
use Drupal\simple_survey\Service\BigQueryConnect;
use Drupal\simple_survey\Service\ResponseExportService;
use Drupal\Component\Datetime\TimeInterface;
use Drupal\Core\File\FileSystemInterface;
use Drupal\Core\Messenger\Messenger;
use Drupal\Core\Url;
use Drupal\simple_survey\Entity\SimpleSurvey;
use Drupal\simple_survey\Entity\SimpleSurveyInterface;
use SplFileObject;

/**
 * Class SimpleSurveyController.
 *
 * @package Drupal\simple_survey\Controller
 */
class SimpleSurveyController extends ControllerBase {

  /**
   * The modules machine name.
   *
   * @var string
   */
  private $moduleName = 'simple_survey';

  /**
   * Drupal\Core\Messenger\MessengerInterface definition.
   *
   * @var \Drupal\Core\Messenger\MessengerInterface
   */
  protected $messenger;

  /**
   * Drupal\Core\Logger\LoggerChannelFactory definition.
   *
   * @var \Drupal\Core\Logger\LoggerChannelInterface
   */
  protected $logger;

  /**
   * Drupal date formatter service.
   *
   * @var \Drupal\Core\Datetime\DateFormatter
   */
  protected $dateFormatter;

  /**
   * Response export service.
   *
   * @var \Drupal\simple_survey\Service\BigQueryConnect
   */
  protected $bigQuery;

  /**
   * Response export service.
   *
   * @var \Drupal\simple_survey\ResponseExportService
   */
  protected $responseExport;

  /**
   * The Drupal Time Service.
   *
   * @var \Drupal\Component\Datetime\TimeInterface
   */
  protected $time;

  /**
   * File System service.
   *
   * @var \Drupal\Core\File\FileSystem
   */
  protected $fileSystem;

  /**
   * Simple Survery Controller constructor.
   *
   * @todo Look into creating a service to handle DI. Doing a janky call in feedbackjs.module
   *
   * @param \Drupal\Core\Messenger\MessengerInterface $messenger
   *   The Drupal messenger service.
   * @param Drupal\Core\Datetime\DateFormatter $dateFormatter
   *   The Drupal date formatter service.
   * @param \Drupal\Core\Logger\LoggerChannelFactoryInterface $logger_factory
   *   The logger factory service.
   * @param \Drupal\simple_survey\Service\BigQueryConnect $big_query
   *   The BigQuery Connection service.
   * @param \Drupal\simple_survey\ResponseExportService $response_export_service
   *   The response export service.
   * @param \Drupal\Component\Datetime\TimeInterface $time
   *   The Drupal time service.
   * @param \Drupal\Core\File\FileSystemInterface $fileSystemInterface
   *   The Drupal file system service.
   */
  public function __construct(
    MessengerInterface $messenger,
    DateFormatter $dateFormatter,
    LoggerChannelFactoryInterface $logger_factory,
    BigQueryConnect $big_query,
    ResponseExportService $response_export_service,
    TimeInterface $time,
    FileSystemInterface $fileSystemInterface) {
    $this->messenger = $messenger;
    $this->dateFormatter = $dateFormatter;
    $this->logger = $logger_factory->get($this->moduleName);
    $this->bigQuery = $big_query;
    $this->responseExport = $response_export_service;
    $this->time = $time;
    $this->fileSystem = $fileSystemInterface;

    $this->modulePath = drupal_get_path('module', $this->moduleName);
  }

  /**
   * Dependency Injection.
   *
   * @inheritDoc
   */
  public static function create(ContainerInterface $container) {
    return new static(
      $container->get('messenger'),
      $container->get('date.formatter'),
      $container->get('logger.factory'),
      $container->get('simple_survey.big_query'),
      $container->get('simple_survey.response_export'),
      $container->get('datetime.time'),
      $container->get('file_system')
    );
  }

  /**
   * Allows user to download the temporary generated response survey.
   *
   * @param string $simple_survey
   *   The survey machine name.
   * @param string $filename
   *   The survey filename.
   *
   * @return mixed
   *   Will return either a file or redirect to the requesting survey.
   */
  public function getTemporaryFile($simple_survey, $filename) {

    $filepath = $this->fileSystem->realpath("temporary://")
      . '/' . $filename;

    if (file_exists($filepath)) {
      $file = new SplFileObject($filepath, 'r');

      $headerResponse = new Response();
      $headerResponse->headers->set('Content-Type', 'test/csv; charset=utf-8');
      $headerResponse->headers->set('Content-Disposition', 'attachment; filename="'
      . $filename);
      $headerResponse->headers->set('Content-Length', $file->getSize());
      $headerResponse->sendHeaders();

      $file->fpassthru();

      return $headerResponse;
    }
    else {
      $this->messenger()->addWarning($this->t(':filename no longer exist. Please generate a new download.', [
        ':filename' => $filename,
      ]));

      return $this->redirect('entity.simple_survey.edit_form', [
        'simple_survey' => $simple_survey,
      ]);
    }
  }

  /**
   * Submits CSV file to BigQuery.
   *
   * @param string $filename
   *   The name of the file to be submitted.
   * @param string $survey
   *   The survey the file is being submitted for.
   * @param string $dataset
   *   The datasest to submit to.
   * @param string $table
   *   The table to submit to.
   * @param array|object $context
   *   The batch context.
   *
   * @return mixed
   *   The
   */
  public static function submitData(
    string $filename,
    string $survey,
    string $dataset,
    string $table,
    &$context) {
    $filepath = \Drupal::service('file_system')->realpath("temporary://")
      . '/' . $filename;
    $bigQuery = \Drupal::service('simple_survey.big_query');
    $messenger = \Drupal::messenger();
    $logger = \Drupal::logger('simple_survey');
    $simpleSurvey = SimpleSurvey::load($survey);
    $isCli = PHP_SAPI === 'cli';

    $contextMessage = t('Sending :filename to :table in BigQuery', [
      ':filename' => $filename,
      ':table' => $table,
    ]);

    $context['message'] = $contextMessage;
    $logger->info($contextMessage);

    $bigQuery->setSurvey($simpleSurvey);

    if (!$bigQuery->checkConfigured()) {
      if (!$isCli) {
        $messenger->addWarning('BigQuery is not configured.');
      }

      $logger->warning('BigQuery is not configured.');
      return;
    }
    else {
      $updated = $bigQuery->updateTable(
        $dataset,
        $table,
        fopen($filepath, 'r')
      );

      // Check if the job has errors.
      if (!$updated) {
        $errorMessage = t('Data to be imported to :dataset.:table could not be sent for :survey.', [
          ':survey' => $simpleSurvey->label(),
          ':dataset' => $dataset,
          ':table' => $table,
        ]);
        $logger->error($errorMessage);
      }
      else {
        $statusMessage = t('Data for :dataset.:table sent to BigQuery for :survey.', [
          ':survey' => $simpleSurvey->label(),
          ':dataset' => $dataset,
          ':table' => $table,
        ]);
        if (!$isCli) {
          $messenger->addMessage($statusMessage);
        }
        $logger->info($statusMessage);
      }
    }

    $context['finished'] = TRUE;
  }

  /**
   * Completion callback for PrintBookForm batch.
   *
   * @param bool $success
   *   Boolean value that specifies batch success.
   * @param array $results
   *   Array that contains results from batch context.
   * @param array $operations
   *   Array that contains batch operations.
   */
  public static function finishedProcessingBq(bool $success, array $results, array $operations) {
    $status = Messenger::TYPE_STATUS;

    if ($success) {
      $message = t('Data sent to BigQuery for :survey.', [
        ':survey' => $results['survey'],
      ]);

      \Drupal::logger('simple_survey')->info($message);
    }
    else {
      $message = t('Could not send data to BigQuery for :survey.', [
        ':survey' => $results['survey'],
      ]);

      $status = Messenger::TYPE_ERROR;
      \Drupal::logger('simple_survey')->error($message);
    }

    \Drupal::messenger()->addMessage($message, $status);
  }

  /**
   * Displays the response as CSV.
   *
   * @return \Symfony\Component\HttpFoundation\Response
   *   Returns a JSON Response.
   */
  public function responseOutput(SimpleSurveyInterface $simple_survey) {
    $fileTime = $this->dateFormatter->format($this->time->getRequestTime(), 'custom', 'YdmHis');
    $filename = $simple_survey->id() . '-survey-export-' . $fileTime . '.csv';
    $survey = $simple_survey->id();

    $batch = [
      'title' => $this->t('Create response download for %survey', [
        '%survey' => $simple_survey->label(),
      ]),
      'operations' => [
        [
          '\Drupal\simple_survey\Service\ResponseExportService::processData',
          [
            $filename,
            $survey,
          ],
        ],
      ],
      'finished' => '\Drupal\simple_survey\Service\ResponseExportService::finishedFileProcessing',
      'init_message' => $this->t('Processing for data from @source', [
        '@source' => $simple_survey->label(),
      ]),
      'progress_message' => $this->t('Time left: @estimate | Time elapsed: @elapsed', [
        '@source' => $simple_survey->label(),
      ]),
      'error_message' => $this->t('The export progress has encountered an error.'),
    ];

    batch_set($batch);

    return batch_process(Url::fromRoute('entity.simple_survey.edit_form', [
      'simple_survey' => $survey,
    ]));
  }

  /**
   * Displays the response as CSV.
   *
   * @return \Symfony\Component\HttpFoundation\Response
   *   Returns a JSON Response.
   */
  public function bigQueryExport(SimpleSurveyInterface $simple_survey) {
    $filename = $simple_survey->id() . '-survey-export.csv';
    $survey = $simple_survey->id();

    $batch = [
      'title' => $this->t('Send Data to BigQuery for %survey', [
        '%survey' => $simple_survey->label(),
      ]),
      'operations' => [
        [
          '\Drupal\simple_survey\Service\ResponseExportService::processData',
          [
            $filename,
            $survey,
          ],
        ],
        [
          '\Drupal\simple_survey\Controller\SimpleSurveyController::submitData',
          [
            $filename,
            $survey,
            $simple_survey->get('bigQueryDataset'),
            $simple_survey->get('bigQueryTable'),
          ],
        ],
      ],
      'finished' => '\Drupal\simple_survey\Controller\SimpleSurveyController::finishedProcessingBq',
      'init_message' => $this->t('Initializing BiqQuery connection for @source', [
        '@source' => $simple_survey->label(),
      ]),
      'progress_message' => $this->t('Data being sent to BiqQuery for @source.', [
        '@source' => $simple_survey->label(),
      ]),
      'error_message' => $this->t('The export progress has encountered an error.'),
    ];

    batch_set($batch);

    return batch_process(Url::fromRoute('entity.simple_survey.edit_form', [
      'simple_survey' => $survey,
    ]));
  }

  /**
   * Submits all data to a bigQuery table via cron.
   */
  public function bigQueryCronUpdate() {
    if (!$this->bigQuery->checkConfigured()) {
      $this->logger->alert('BigQuery is not configured.');
    }
    else {
      $surveys = SimpleSurvey::loadMultiple();

      foreach ($surveys as $survey) {
        if (!$survey->isSurveyActive()) {
          continue;
        }

        $this->responseExport->survey = $survey;
        $csv = $this->responseExport->convertDataToCsv();

        $updated = $this->bigQuery->updateTable('survey_tool', 'survey_response', $csv);

        // Check if the job has errors.
        if ($updated) {
          $this->logger->info('Completed Updating BigQuery Table for ' . $survey->label());
        }
      }
    }
  }

  /**
   * Manual submission to BigQuery.
   *
   * @return \Symfony\Component\HttpFoundation\Response
   *   Returns response object.
   */
  public function bigQueryManualUpdate(SimpleSurveyInterface $simple_survey) {
    $fileTime = $this->dateFormatter->format($this->time->getRequestTime(), 'custom', 'YdmHis');
    $filename = $simple_survey->id() . '-survey-export-' . $fileTime . '.csv';
    $survey = $simple_survey->id();

    $batch = [
      'title' => $this->t('Send Data to BigQuery for %survey', [
        '%survey' => $simple_survey->label(),
      ]),
      'operations' => [
        [
          '\Drupal\simple_survey\Service\ResponseExportService::processData',
          [
            $filename,
            $survey,
          ],
        ],
        [
          '\Drupal\simple_survey\Controller\SimpleSurveyController::submitData',
          [
            $filename,
            $survey,
            $simple_survey->get('bigQueryDataset'),
            $simple_survey->get('bigQueryTable'),
          ],
        ],
      ],
      'finished' => '\Drupal\simple_survey\Controller\SimpleSurveyController::finishedProcessingBq',
      'init_message' => $this->t('Initializing BiqQuery connection for @source', [
        '@source' => $simple_survey->label(),
      ]),
      'progress_message' => $this->t('Time left: @estimate | Time elapsed: @elapsed', [
        '@source' => $simple_survey->label(),
      ]),
      'error_message' => $this->t('The export progress has encountered an error.'),
    ];

    batch_set($batch);

    return batch_process(Url::fromRoute('entity.simple_survey.edit_form', [
      'simple_survey' => $survey,
    ]));
  }

}
